ninja_build: A build system with a focus on speed
=================================================

Description
-----------

Ninja is a small build system with a focus on speed.

License
-------

Apache License 2.0


Upstream Contact
----------------

https://ninja-build.org/

